==> swagger-api__apidom-ns-openapi-3-0-0.69.1.jar: META-INF/resources/webjars/swagger-api__apidom-ns-openapi-3-0/0.69.1/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

## [0.69.1](https://github.com/swagger-api/apidom/compare/v0.69.0...v0.69.1) (2023-03-28)

**Note:** Version bump only for package @swagger-api/apidom-ns-openapi-3-0

# [0.69.0](https://github.com/swagger-api/apidom/compare/v0.68.1...v0.69.0) (2023-02-28)

### Features

- add support for publishing to npmjs.com ([#2597](https://github.com/swagger-api/apidom/issues/2597)) ([5ac3cd9](https://github.com/swagger-api/apidom/commit/5ac3cd9a83bbe3b4ce2fac732633fb179cd9747f)), closes [#2290](https://github.com/swagger-api/apidom/issues/2290)

## [0.68.1](https://github.com/swagger-api/apidom/compare/v0.68.0...v0.68.1) (2023-02-20)

### Bug Fixes

- **build:** map all side effects within the packages ([#2574](https://github.com/swagger-api/apidom/issues/2574)) ([ed1dcf5](https://github.com/swagger-api/apidom/commit/ed1dcf5a17a801776eb93c1d4262024194a58fea)), closes [#2566](https://github.com/swagger-api/apidom/issues/2566)

# [0.68.0](https://github.com/swagger-api/apidom/compare/v0.67.1...v0.68.0) (2023-02-16)

### Features

- **ns-openapi-3-0:** add sideEffects field to package.json ([6dae3e0](https://github.com/swagger-api/apidom/commit/6dae3e0e95a788b0bbeffc24dd42d30a502e8bc9)), closes [#2566](https://github.com/swagger-api/apidom/issues/2566)

## [0.67.1](https://github.com/swagger-api/apidom/compare/v0.67.0...v0.67.1) (2023-02-15)

### Bug Fixes

- **deps:** relax @babel/runtime-corejs3 version ([#2563](https://github.com/swagger-api/apidom/issues/2563)) ([3523a14](https://github.com/swagger-api/apidom/commit/3523a145a8390bb85139d9a8c3919b0c4ef75962)), closes [#2562](https://github.com/swagger-api/apidom/issues/2562)

# [0.67.0](https://github.com/swagger-api/apidom/compare/v0.66.0...v0.67.0) (2023-02-07)

**Note:** Version bump only for package @swagger-api/apidom-ns-openapi-3-0

# [0.66.0](https://github.com/swagger-api/apidom/compare/v0.65.0...v0.66.0) (2023-01-25)

**Note:** Version bump only for package @swagger-api/apidom-ns-openapi-3-0

# [0.65.0](https://github.com/swagger-api/apidom/compare/v0.64.0...v0.65.0) (2023-01-20)

**Note:** Version bump only for package @swagger-api/apidom-ns-openapi-3-0

# [0.64.0](https://github.com/swagger-api/apidom/compare/v0.63.1...v0.64.0) (2023-01-16)

**Note:** Version bump only for package @swagger-api/apidom-ns-openapi-3-0

# [0.63.0](https://github.com/swagger-api/apidom/compare/v0.62.1...v0.63.0) (2023-01-04)

**Note:** Version bump only for package @swagger-api/apidom-ns-openapi-3-0

## [0.62.1](https://github.com/swagger-api/apidom/compare/v0.62.0...v0.62.1) (2023-01-04)

**Note:** Version bump only for package @swagger-api/apidom-ns-openapi-3-0

# [0.62.0](https://github.com/swagger-api/apidom/compare/v0.61.0...v0.62.0) (2023-01-03)

### Features

- **core:** expose refractor plugins dispatcher as public API ([#2427](https://github.com/swagger-api/apidom/issues/2427)) ([a909e76](https://github.com/swagger-api/apidom/commit/a909e76c78bc952f1b8f64691cd6b943b957a786)), closes [#2362](https://github.com/swagger-api/apidom/issues/2362)
- **ns-openapi-3-1:** add Header.example(s) normalization ([#2429](https://github.com/swagger-api/apidom/issues/2429)) ([c8cd9d4](https://github.com/swagger-api/apidom/commit/c8cd9d447c7ccc740ff0bde638afb4e96a9a052c)), closes [#2362](https://github.com/swagger-api/apidom/issues/2362)

# [0.61.0](https://github.com/swagger-api/apidom/compare/v0.60.0...v0.61.0) (2022-12-31)

**Note:** Version bump only for package @swagger-api/apidom-ns-openapi-3-0

# [0.60.0](https://github.com/swagger-api/apidom/compare/v0.59.0...v0.60.0) (2022-12-28)

**Note:** Version bump only for package @swagger-api/apidom-ns-openapi-3-0

# [0.59.0](https://github.com/swagger-api/apidom/compare/v0.58.0...v0.59.0) (2022-12-27)

**Note:** Version bump only for package @swagger-api/apidom-ns-openapi-3-0

# [0.58.0](https://github.com/swagger-api/apidom/compare/v0.57.0...v0.58.0) (2022-12-16)

**Note:** Version bump only for package @swagger-api/apidom-ns-openapi-3-0

# [0.57.0](https://github.com/swagger-api/apidom/compare/v0.56.3...v0.57.0) (2022-12-08)

### Bug Fixes

- **ns-openapi:** fix copy&paste typos in getters & setters ([#2311](https://github.com/swagger-api/apidom/issues/2311)) ([b498a99](https://github.com/swagger-api/apidom/commit/b498a99b931f6910d641531a2b5789f45e5f7b14))

## [0.56.2](https://github.com/swagger-api/apidom/compare/v0.56.1...v0.56.2) (2022-11-16)

**Note:** Version bump only for package @swagger-api/apidom-ns-openapi-3-0

## [0.56.1](https://github.com/swagger-api/apidom/compare/v0.56.0...v0.56.1) (2022-11-11)

### Bug Fixes

- **ls:** fix OpenAPI Responses patterned fields linting ([1751c8d](https://github.com/swagger-api/apidom/commit/1751c8dea7627997b00f3cee089a1774bc6e1e08))

# [0.56.0](https://github.com/swagger-api/apidom/compare/v0.55.1...v0.56.0) (2022-11-04)

**Note:** Version bump only for package @swagger-api/apidom-ns-openapi-3-0

# [0.55.0](https://github.com/swagger-api/apidom/compare/v0.54.0...v0.55.0) (2022-11-04)

**Note:** Version bump only for package @swagger-api/apidom-ns-openapi-3-0

# [0.54.0](https://github.com/swagger-api/apidom/compare/v0.53.0...v0.54.0) (2022-10-28)

**Note:** Version bump only for package @swagger-api/apidom-ns-openapi-3-0

# [0.53.0](https://github.com/swagger-api/apidom/compare/v0.52.0...v0.53.0) (2022-10-27)

**Note:** Version bump only for package @swagger-api/apidom-ns-openapi-3-0

# [0.52.0](https://github.com/swagger-api/apidom/compare/v0.51.1...v0.52.0) (2022-10-25)

**Note:** Version bump only for package @swagger-api/apidom-ns-openapi-3-0

## [0.51.1](https://github.com/swagger-api/apidom/compare/v0.51.0...v0.51.1) (2022-10-21)

**Note:** Version bump only for package @swagger-api/apidom-ns-openapi-3-0

# [0.51.0](https://github.com/swagger-api/apidom/compare/v0.50.0...v0.51.0) (2022-10-20)

### Bug Fixes

- **ns-openapi-3-0:** drop support of extensions from Discriminator ([#2147](https://github.com/swagger-api/apidom/issues/2147)) ([4bc2bde](https://github.com/swagger-api/apidom/commit/4bc2bde70d9b41a15819195a4a3d1882f8b385ef))

# [0.50.0](https://github.com/swagger-api/apidom/compare/v0.49.0...v0.50.0) (2022-10-13)

**Note:** Version bump only for package @swagger-api/apidom-ns-openapi-3-0

# [0.49.0](https://github.com/swagger-api/apidom/compare/v0.48.0...v0.49.0) (2022-10-11)

**Note:** Version bump only for package @swagger-api/apidom-ns-openapi-3-0

# [0.48.0](https://github.com/swagger-api/apidom/compare/v0.47.0...v0.48.0) (2022-10-04)

**Note:** Version bump only for package @swagger-api/apidom-ns-openapi-3-0

# [0.47.0](https://github.com/swagger-api/apidom/compare/v0.46.0...v0.47.0) (2022-09-29)

**Note:** Version bump only for package @swagger-api/apidom-ns-openapi-3-0

# [0.46.0](https://github.com/swagger-api/apidom/compare/v0.45.0...v0.46.0) (2022-09-21)

**Note:** Version bump only for package @swagger-api/apidom-ns-openapi-3-0

# [0.45.0](https://github.com/swagger-api/apidom/compare/v0.44.0...v0.45.0) (2022-09-13)

**Note:** Version bump only for package @swagger-api/apidom-ns-openapi-3-0

# [0.44.0](https://github.com/swagger-api/apidom/compare/v0.43.0...v0.44.0) (2022-09-05)

**Note:** Version bump only for package @swagger-api/apidom-ns-openapi-3-0

# [0.43.0](https://github.com/swagger-api/apidom/compare/v0.42.0...v0.43.0) (2022-08-31)

### Features

- add JSON parser adapter for OpenAPI 3.0.x namespacd ([#1948](https://github.com/swagger-api/apidom/issues/1948)) ([ce254b2](https://github.com/swagger-api/apidom/commit/ce254b236082667e982b99d6fa32f565ffae1730)), closes [#1892](https://github.com/swagger-api/apidom/issues/1892)

# [0.42.0](https://github.com/swagger-api/apidom/compare/v0.41.1...v0.42.0) (2022-08-30)

### Features

- **ns-openapi-3-0:** add replace empty elements refractor plugin ([#1939](https://github.com/swagger-api/apidom/issues/1939)) ([e34fbea](https://github.com/swagger-api/apidom/commit/e34fbea33d8c1ba15240d04bca92db3eb2454afb)), closes [#1889](https://github.com/swagger-api/apidom/issues/1889)
- **ns-openapi-3-0:** feat add supporting code ([#1926](https://github.com/swagger-api/apidom/issues/1926)) ([8a6ebb4](https://github.com/swagger-api/apidom/commit/8a6ebb40539b1c7e53270e117946758cac5b5df0)), closes [#1888](https://github.com/swagger-api/apidom/issues/1888)
- **ns-openapi-3-0:** implement namespace elements ([#1914](https://github.com/swagger-api/apidom/issues/1914)) ([0817854](https://github.com/swagger-api/apidom/commit/0817854d9da7130abf32b89cae0dae79dab76858)), closes [#1887](https://github.com/swagger-api/apidom/issues/1887)
- **ns-openapi-3-0:** implement NCE elements ([#1919](https://github.com/swagger-api/apidom/issues/1919)) ([46420b9](https://github.com/swagger-api/apidom/commit/46420b909e452d2060fdbe7c46d92ac9e053cbfa)), closes [#1887](https://github.com/swagger-api/apidom/issues/1887)
- **ns-openapi-3-0:** implement refractor layer ([#1927](https://github.com/swagger-api/apidom/issues/1927)) ([7c95c9f](https://github.com/swagger-api/apidom/commit/7c95c9f408ce620ce2c3e4f18a00404892f4104b)), closes [#1886](https://github.com/swagger-api/apidom/issues/1886)
- **ns-openapi-3-0:** implement Schema element ([#1918](https://github.com/swagger-api/apidom/issues/1918)) ([b51d107](https://github.com/swagger-api/apidom/commit/b51d107eee24fed1f177b2d8f14670c63e53155a)), closes [#1887](https://github.com/swagger-api/apidom/issues/1887)

==> swagger-api__apidom-ns-openapi-3-0-0.70.0.jar: META-INF/resources/webjars/swagger-api__apidom-ns-openapi-3-0/0.70.0/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

# [0.70.0](https://github.com/swagger-api/apidom/compare/v0.69.3...v0.70.0) (2023-05-23)

**Note:** Version bump only for package @swagger-api/apidom-ns-openapi-3-0

## [0.69.3](https://github.com/swagger-api/apidom/compare/v0.69.2...v0.69.3) (2023-04-27)

**Note:** Version bump only for package @swagger-api/apidom-ns-openapi-3-0

## [0.69.2](https://github.com/swagger-api/apidom/compare/v0.69.1...v0.69.2) (2023-04-03)

**Note:** Version bump only for package @swagger-api/apidom-ns-openapi-3-0

## [0.69.1](https://github.com/swagger-api/apidom/compare/v0.69.0...v0.69.1) (2023-03-28)

**Note:** Version bump only for package @swagger-api/apidom-ns-openapi-3-0

# [0.69.0](https://github.com/swagger-api/apidom/compare/v0.68.1...v0.69.0) (2023-02-28)

### Features

- add support for publishing to npmjs.com ([#2597](https://github.com/swagger-api/apidom/issues/2597)) ([5ac3cd9](https://github.com/swagger-api/apidom/commit/5ac3cd9a83bbe3b4ce2fac732633fb179cd9747f)), closes [#2290](https://github.com/swagger-api/apidom/issues/2290)

## [0.68.1](https://github.com/swagger-api/apidom/compare/v0.68.0...v0.68.1) (2023-02-20)

### Bug Fixes

- **build:** map all side effects within the packages ([#2574](https://github.com/swagger-api/apidom/issues/2574)) ([ed1dcf5](https://github.com/swagger-api/apidom/commit/ed1dcf5a17a801776eb93c1d4262024194a58fea)), closes [#2566](https://github.com/swagger-api/apidom/issues/2566)

# [0.68.0](https://github.com/swagger-api/apidom/compare/v0.67.1...v0.68.0) (2023-02-16)

### Features

- **ns-openapi-3-0:** add sideEffects field to package.json ([6dae3e0](https://github.com/swagger-api/apidom/commit/6dae3e0e95a788b0bbeffc24dd42d30a502e8bc9)), closes [#2566](https://github.com/swagger-api/apidom/issues/2566)

## [0.67.1](https://github.com/swagger-api/apidom/compare/v0.67.0...v0.67.1) (2023-02-15)

### Bug Fixes

- **deps:** relax @babel/runtime-corejs3 version ([#2563](https://github.com/swagger-api/apidom/issues/2563)) ([3523a14](https://github.com/swagger-api/apidom/commit/3523a145a8390bb85139d9a8c3919b0c4ef75962)), closes [#2562](https://github.com/swagger-api/apidom/issues/2562)

# [0.67.0](https://github.com/swagger-api/apidom/compare/v0.66.0...v0.67.0) (2023-02-07)

**Note:** Version bump only for package @swagger-api/apidom-ns-openapi-3-0

# [0.66.0](https://github.com/swagger-api/apidom/compare/v0.65.0...v0.66.0) (2023-01-25)

**Note:** Version bump only for package @swagger-api/apidom-ns-openapi-3-0

# [0.65.0](https://github.com/swagger-api/apidom/compare/v0.64.0...v0.65.0) (2023-01-20)

**Note:** Version bump only for package @swagger-api/apidom-ns-openapi-3-0

# [0.64.0](https://github.com/swagger-api/apidom/compare/v0.63.1...v0.64.0) (2023-01-16)

**Note:** Version bump only for package @swagger-api/apidom-ns-openapi-3-0

# [0.63.0](https://github.com/swagger-api/apidom/compare/v0.62.1...v0.63.0) (2023-01-04)

**Note:** Version bump only for package @swagger-api/apidom-ns-openapi-3-0

## [0.62.1](https://github.com/swagger-api/apidom/compare/v0.62.0...v0.62.1) (2023-01-04)

**Note:** Version bump only for package @swagger-api/apidom-ns-openapi-3-0

# [0.62.0](https://github.com/swagger-api/apidom/compare/v0.61.0...v0.62.0) (2023-01-03)

### Features

- **core:** expose refractor plugins dispatcher as public API ([#2427](https://github.com/swagger-api/apidom/issues/2427)) ([a909e76](https://github.com/swagger-api/apidom/commit/a909e76c78bc952f1b8f64691cd6b943b957a786)), closes [#2362](https://github.com/swagger-api/apidom/issues/2362)
- **ns-openapi-3-1:** add Header.example(s) normalization ([#2429](https://github.com/swagger-api/apidom/issues/2429)) ([c8cd9d4](https://github.com/swagger-api/apidom/commit/c8cd9d447c7ccc740ff0bde638afb4e96a9a052c)), closes [#2362](https://github.com/swagger-api/apidom/issues/2362)

# [0.61.0](https://github.com/swagger-api/apidom/compare/v0.60.0...v0.61.0) (2022-12-31)

**Note:** Version bump only for package @swagger-api/apidom-ns-openapi-3-0

# [0.60.0](https://github.com/swagger-api/apidom/compare/v0.59.0...v0.60.0) (2022-12-28)

**Note:** Version bump only for package @swagger-api/apidom-ns-openapi-3-0

# [0.59.0](https://github.com/swagger-api/apidom/compare/v0.58.0...v0.59.0) (2022-12-27)

**Note:** Version bump only for package @swagger-api/apidom-ns-openapi-3-0

# [0.58.0](https://github.com/swagger-api/apidom/compare/v0.57.0...v0.58.0) (2022-12-16)

**Note:** Version bump only for package @swagger-api/apidom-ns-openapi-3-0

# [0.57.0](https://github.com/swagger-api/apidom/compare/v0.56.3...v0.57.0) (2022-12-08)

### Bug Fixes

- **ns-openapi:** fix copy&paste typos in getters & setters ([#2311](https://github.com/swagger-api/apidom/issues/2311)) ([b498a99](https://github.com/swagger-api/apidom/commit/b498a99b931f6910d641531a2b5789f45e5f7b14))

## [0.56.2](https://github.com/swagger-api/apidom/compare/v0.56.1...v0.56.2) (2022-11-16)

**Note:** Version bump only for package @swagger-api/apidom-ns-openapi-3-0

## [0.56.1](https://github.com/swagger-api/apidom/compare/v0.56.0...v0.56.1) (2022-11-11)

### Bug Fixes

- **ls:** fix OpenAPI Responses patterned fields linting ([1751c8d](https://github.com/swagger-api/apidom/commit/1751c8dea7627997b00f3cee089a1774bc6e1e08))

# [0.56.0](https://github.com/swagger-api/apidom/compare/v0.55.1...v0.56.0) (2022-11-04)

**Note:** Version bump only for package @swagger-api/apidom-ns-openapi-3-0

# [0.55.0](https://github.com/swagger-api/apidom/compare/v0.54.0...v0.55.0) (2022-11-04)

**Note:** Version bump only for package @swagger-api/apidom-ns-openapi-3-0

# [0.54.0](https://github.com/swagger-api/apidom/compare/v0.53.0...v0.54.0) (2022-10-28)

**Note:** Version bump only for package @swagger-api/apidom-ns-openapi-3-0

# [0.53.0](https://github.com/swagger-api/apidom/compare/v0.52.0...v0.53.0) (2022-10-27)

**Note:** Version bump only for package @swagger-api/apidom-ns-openapi-3-0

# [0.52.0](https://github.com/swagger-api/apidom/compare/v0.51.1...v0.52.0) (2022-10-25)

**Note:** Version bump only for package @swagger-api/apidom-ns-openapi-3-0

## [0.51.1](https://github.com/swagger-api/apidom/compare/v0.51.0...v0.51.1) (2022-10-21)

**Note:** Version bump only for package @swagger-api/apidom-ns-openapi-3-0

# [0.51.0](https://github.com/swagger-api/apidom/compare/v0.50.0...v0.51.0) (2022-10-20)

### Bug Fixes

- **ns-openapi-3-0:** drop support of extensions from Discriminator ([#2147](https://github.com/swagger-api/apidom/issues/2147)) ([4bc2bde](https://github.com/swagger-api/apidom/commit/4bc2bde70d9b41a15819195a4a3d1882f8b385ef))

# [0.50.0](https://github.com/swagger-api/apidom/compare/v0.49.0...v0.50.0) (2022-10-13)

**Note:** Version bump only for package @swagger-api/apidom-ns-openapi-3-0

# [0.49.0](https://github.com/swagger-api/apidom/compare/v0.48.0...v0.49.0) (2022-10-11)

**Note:** Version bump only for package @swagger-api/apidom-ns-openapi-3-0

# [0.48.0](https://github.com/swagger-api/apidom/compare/v0.47.0...v0.48.0) (2022-10-04)

**Note:** Version bump only for package @swagger-api/apidom-ns-openapi-3-0

# [0.47.0](https://github.com/swagger-api/apidom/compare/v0.46.0...v0.47.0) (2022-09-29)

**Note:** Version bump only for package @swagger-api/apidom-ns-openapi-3-0

# [0.46.0](https://github.com/swagger-api/apidom/compare/v0.45.0...v0.46.0) (2022-09-21)

**Note:** Version bump only for package @swagger-api/apidom-ns-openapi-3-0

# [0.45.0](https://github.com/swagger-api/apidom/compare/v0.44.0...v0.45.0) (2022-09-13)

**Note:** Version bump only for package @swagger-api/apidom-ns-openapi-3-0

# [0.44.0](https://github.com/swagger-api/apidom/compare/v0.43.0...v0.44.0) (2022-09-05)

**Note:** Version bump only for package @swagger-api/apidom-ns-openapi-3-0

# [0.43.0](https://github.com/swagger-api/apidom/compare/v0.42.0...v0.43.0) (2022-08-31)

### Features

- add JSON parser adapter for OpenAPI 3.0.x namespacd ([#1948](https://github.com/swagger-api/apidom/issues/1948)) ([ce254b2](https://github.com/swagger-api/apidom/commit/ce254b236082667e982b99d6fa32f565ffae1730)), closes [#1892](https://github.com/swagger-api/apidom/issues/1892)

# [0.42.0](https://github.com/swagger-api/apidom/compare/v0.41.1...v0.42.0) (2022-08-30)

### Features

- **ns-openapi-3-0:** add replace empty elements refractor plugin ([#1939](https://github.com/swagger-api/apidom/issues/1939)) ([e34fbea](https://github.com/swagger-api/apidom/commit/e34fbea33d8c1ba15240d04bca92db3eb2454afb)), closes [#1889](https://github.com/swagger-api/apidom/issues/1889)
- **ns-openapi-3-0:** feat add supporting code ([#1926](https://github.com/swagger-api/apidom/issues/1926)) ([8a6ebb4](https://github.com/swagger-api/apidom/commit/8a6ebb40539b1c7e53270e117946758cac5b5df0)), closes [#1888](https://github.com/swagger-api/apidom/issues/1888)
- **ns-openapi-3-0:** implement namespace elements ([#1914](https://github.com/swagger-api/apidom/issues/1914)) ([0817854](https://github.com/swagger-api/apidom/commit/0817854d9da7130abf32b89cae0dae79dab76858)), closes [#1887](https://github.com/swagger-api/apidom/issues/1887)
- **ns-openapi-3-0:** implement NCE elements ([#1919](https://github.com/swagger-api/apidom/issues/1919)) ([46420b9](https://github.com/swagger-api/apidom/commit/46420b909e452d2060fdbe7c46d92ac9e053cbfa)), closes [#1887](https://github.com/swagger-api/apidom/issues/1887)
- **ns-openapi-3-0:** implement refractor layer ([#1927](https://github.com/swagger-api/apidom/issues/1927)) ([7c95c9f](https://github.com/swagger-api/apidom/commit/7c95c9f408ce620ce2c3e4f18a00404892f4104b)), closes [#1886](https://github.com/swagger-api/apidom/issues/1886)
- **ns-openapi-3-0:** implement Schema element ([#1918](https://github.com/swagger-api/apidom/issues/1918)) ([b51d107](https://github.com/swagger-api/apidom/commit/b51d107eee24fed1f177b2d8f14670c63e53155a)), closes [#1887](https://github.com/swagger-api/apidom/issues/1887)
